@@ -7,7 +7,7 @@
  * (The transparency stuff was inspired by -- pulled from the still-warm 
  * body of -- wterm.  Many thanks to wterm's "anonymous coder!")
  * 
- * $Id: main.c,v 1.11 2002/07/01 06:24:02 bob Exp $
+ * $Id: main.c,v 1.13 2004/02/20 22:31:53 bob Exp $
  *
  *
  *
@@ -40,6 +40,8 @@
 #include "util.h"
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
+#include <X11/Xos.h>
+#include <X11/Xatom.h>
 #include <assert.h>
 #include <errno.h>
 #include <stdio.h>
@@ -294,6 +296,59 @@ void init_console(const char *console,
 }
   
 
+/* Return the root window, or a virtual root window if any. */
+static Window root_window(Display *display) {
+    Atom __SWM_VROOT = XInternAtom(display, "__SWM_VROOT", False);
+
+    if (__SWM_VROOT != None) {
+        Window unused, *windows;
+        unsigned int count;
+
+        if (XQueryTree(display, DefaultRootWindow (display), &unused, &unused,
+		      &windows, &count)) {
+            int i;
+
+            for (i=0; i<count; i++) {
+                Atom type;
+                int format;
+                unsigned long nitems, bytes_after_return;
+                Window *virtual_root_window;
+
+                if (XGetWindowProperty(display, windows[i], __SWM_VROOT,
+                          0, 1, False, XA_WINDOW, &type, &format,
+                          &nitems, &bytes_after_return,
+                          (unsigned char **) &virtual_root_window) == Success){
+                    if (type != None) {
+                        if (type == XA_WINDOW) {
+                            XFree(windows);
+                            return *virtual_root_window;
+                        } else {
+                            fprintf(stderr,
+                                    "__SWM_VROOT property type mismatch");
+                        }
+                    }
+                } else {
+                    fprintf(stderr,
+                         "failed to get __SWM_VROOT property on window 0x%lx",
+                         windows[i]);
+                }
+            }
+
+        if (count)
+            XFree(windows);
+        } else {
+            fprintf(stderr, "Can't query tree on root window 0x%lx",
+                 DefaultRootWindow (display));
+        }
+    } else {
+        /* This shouldn't happen. The Xlib documentation is wrong BTW. */
+        fprintf (stderr, "Can't intern atom __SWM_VROOT");
+    }
+
+    return DefaultRootWindow (display);
+}
+
+
 void init_window(InitOptions *io, WindowSettings *ws) {
     XGCValues values;
 
@@ -346,7 +401,7 @@ void init_window(InitOptions *io, WindowSettings *ws) {
     ws->swa.event_mask = ExposureMask;
     ws->swa.override_redirect = True;
      
-    ws->win = XCreateWindow(ws->dpy, DefaultRootWindow(ws->dpy), 
+    ws->win = XCreateWindow(ws->dpy, root_window(ws->dpy), 
                 ws->x_root, ws->y_root,
                 ws->width, ws->height, io->bw, CopyFromParent, CopyFromParent,
                 DefaultVisual(ws->dpy, DefaultScreen(ws->dpy)),
