@@ -5,7 +5,7 @@
  * Original version: Copyright (C) 1998, 1999  Eric Youngblut
  *
  * 
- * $Id: util.c,v 1.3 2000/10/10 02:17:53 bob Exp $
+ * $Id: util.c,v 1.4 2004/02/20 22:07:42 bob Exp $
  *
  *
  *
@@ -53,16 +53,16 @@ XFontStruct* load_font(const char* s, Display *dpy) {
 
 
 unsigned long load_color(const char* s, Display *dpy) {
-    XColor ce, cs;
+    XColor ce;
     Colormap colormap = DefaultColormap(dpy, DefaultScreen(dpy));
 
-    if (XLookupColor(dpy, colormap, s, &ce, &cs)) {
+    if (XParseColor(dpy, colormap, s, &ce)) {
         if (XAllocColor(dpy, colormap, &ce)) return ce.pixel;
 	
         fprintf(stderr, "Warning: could not allocate color\n");
         return WhitePixel(dpy, DefaultScreen(dpy));
     }
 
-    fprintf(stderr, "Warning: could not lookup color\n");
+    fprintf(stderr, "Warning: could not parse color\n");
     return WhitePixel(dpy, DefaultScreen(dpy));
 }
